[![PyPI](https://img.shields.io/pypi/v/hht.svg)]()

# Introduction

This is a Python implementation of Hilbert-Huang Transform (HHT).

## Requirement
Python 3

## How to install
Simply
```bash
pip install hht
```

## Usage Example

```python
import hht
```

## License
MIT License

Copyright (c) 2018 Feng Zhu
